@@ -238,15 +238,25 @@ runner.runnerRole.addManagedPolicy(
 
 ### Custom Gitlab Runner EBS szie
 
-> 2020/08/22 , you can change you want ebs size.
+> 2025/01/03 , you can change you want ebs size.
 
 ```python
 import { GitlabContainerRunner } from 'cdk-gitlab-runner';
-
+// on-demand instance
 new GitlabContainerRunner(stack, 'testing', {
   gitlabtoken: 'glrt-GITLABTOKEN',
   gitlabRunnerVersion: '15.10',
-  ebsSize: 50,
+  onDemandEbsConfig: BlockDeviceVolume.ebs(60),
+});
+
+// spotfleet instance
+new GitlabContainerRunner(stack, 'testing', {
+  gitlabtoken: 'glrt-GITLABTOKEN',
+  gitlabRunnerVersion: '15.10',
+  spotFleet: true,
+  spotEbsConfig: {
+    volumeSize: 50,
+  },
 });
 ```
 
@@ -498,8 +508,10 @@ class GitlabContainerRunner(
         gitlaburl: typing.Optional[builtins.str] = None,
         instance_interruption_behavior: typing.Optional["InstanceInterruptionBehavior"] = None,
         key_name: typing.Optional[builtins.str] = None,
+        on_demand_ebs_config: typing.Optional[_aws_cdk_aws_ec2_ceddda9d.BlockDeviceVolume] = None,
         runner_description: typing.Optional[builtins.str] = None,
         selfvpc: typing.Optional[_aws_cdk_aws_ec2_ceddda9d.IVpc] = None,
+        spot_ebs_config: typing.Optional[typing.Union[_aws_cdk_aws_ec2_ceddda9d.CfnLaunchTemplate.EbsProperty, typing.Dict[builtins.str, typing.Any]]] = None,
         spot_fleet: typing.Optional[builtins.bool] = None,
         tags: typing.Optional[typing.Sequence[builtins.str]] = None,
         valid_until: typing.Optional[builtins.str] = None,
@@ -512,7 +524,7 @@ class GitlabContainerRunner(
         :param gitlabtoken: (experimental) Gitlab token for the Register Runner . Default: - You must to give the token !!!
         :param concurrent_jobs: (experimental) Gitlab Runner concurrent job configuration. Default: - concurrentJobs=1
         :param docker_volumes: (experimental) add another Gitlab Container Runner Docker Volumes Path at job runner runtime. more detail see https://docs.gitlab.com/runner/configuration/advanced-configuration.html#the-runnersdocker-section Default: - already mount "/var/run/docker.sock:/var/run/docker.sock"
-        :param ebs_size: (experimental) Gitlab Runner instance EBS size . Default: - ebsSize=60
+        :param ebs_size: (deprecated) Gitlab Runner instance EBS size .
         :param ec2iamrole: (experimental) IAM role for the Gitlab Runner Instance . Default: - new Role for Gitlab Runner Instance , attach AmazonSSMManagedInstanceCore Policy .
         :param ec2type: (experimental) Runner default EC2 instance type. Default: - t3.micro
         :param enabled_imd_sv2: (experimental) Enabled IMDSv2. more detail see https://docs.aws.amazon.com/zh_tw/AWSEC2/latest/UserGuide/configuring-instance-metadata-service.html Default: - false
@@ -520,8 +532,10 @@ class GitlabContainerRunner(
         :param gitlaburl: (experimental) Gitlab Runner register url . Default: - gitlaburl='https://gitlab.com/' , please use https://yourgitlab.com/ do not use https://yourgitlab.com
         :param instance_interruption_behavior: (experimental) The behavior when a Spot Runner Instance is interrupted. Default: - InstanceInterruptionBehavior.TERMINATE , !!! only support spotfleet runner !!! .
         :param key_name: (experimental) SSH key name. Default: - no ssh key will be assigned , !!! only support spotfleet runner !!! .
+        :param on_demand_ebs_config: (experimental) Gitlab Runner instance EBS config. Default: - onDemandEbsConfig=BlockDeviceVolume.ebs(60)
         :param runner_description: (experimental) Gitlab Runner description. Default: - runnerDescription='Docker Runner'
         :param selfvpc: (experimental) VPC for the Gitlab Runner . Default: - new VPC will be created , 1 Vpc , 2 Public Subnet .
+        :param spot_ebs_config: (experimental) Gitlab Runner instance EBS config. Default: - spotEbsConfig={ volumeSize: 60}
         :param spot_fleet: (experimental) Gitlab Runner instance Use Spot Fleet or not ?!. Default: - spotFleet=false
         :param tags: (experimental) tags for the runner Unsupported Gitlab Runner 15.10 and later. Default: - ['runner', 'gitlab', 'awscdk']
         :param valid_until: (experimental) the time when the spot fleet allocation expires. Default: - no expiration , !!! only support spotfleet runner !!! .
@@ -546,8 +560,10 @@ class GitlabContainerRunner(
             gitlaburl=gitlaburl,
             instance_interruption_behavior=instance_interruption_behavior,
             key_name=key_name,
+            on_demand_ebs_config=on_demand_ebs_config,
             runner_description=runner_description,
             selfvpc=selfvpc,
+            spot_ebs_config=spot_ebs_config,
             spot_fleet=spot_fleet,
             tags=tags,
             valid_until=valid_until,
@@ -660,8 +676,10 @@ class GitlabContainerRunner(
         "gitlaburl": "gitlaburl",
         "instance_interruption_behavior": "instanceInterruptionBehavior",
         "key_name": "keyName",
+        "on_demand_ebs_config": "onDemandEbsConfig",
         "runner_description": "runnerDescription",
         "selfvpc": "selfvpc",
+        "spot_ebs_config": "spotEbsConfig",
         "spot_fleet": "spotFleet",
         "tags": "tags",
         "valid_until": "validUntil",
@@ -684,8 +702,10 @@ class GitlabContainerRunnerProps:
         gitlaburl: typing.Optional[builtins.str] = None,
         instance_interruption_behavior: typing.Optional["InstanceInterruptionBehavior"] = None,
         key_name: typing.Optional[builtins.str] = None,
+        on_demand_ebs_config: typing.Optional[_aws_cdk_aws_ec2_ceddda9d.BlockDeviceVolume] = None,
         runner_description: typing.Optional[builtins.str] = None,
         selfvpc: typing.Optional[_aws_cdk_aws_ec2_ceddda9d.IVpc] = None,
+        spot_ebs_config: typing.Optional[typing.Union[_aws_cdk_aws_ec2_ceddda9d.CfnLaunchTemplate.EbsProperty, typing.Dict[builtins.str, typing.Any]]] = None,
         spot_fleet: typing.Optional[builtins.bool] = None,
         tags: typing.Optional[typing.Sequence[builtins.str]] = None,
         valid_until: typing.Optional[builtins.str] = None,
@@ -697,7 +717,7 @@ class GitlabContainerRunnerProps:
         :param gitlabtoken: (experimental) Gitlab token for the Register Runner . Default: - You must to give the token !!!
         :param concurrent_jobs: (experimental) Gitlab Runner concurrent job configuration. Default: - concurrentJobs=1
         :param docker_volumes: (experimental) add another Gitlab Container Runner Docker Volumes Path at job runner runtime. more detail see https://docs.gitlab.com/runner/configuration/advanced-configuration.html#the-runnersdocker-section Default: - already mount "/var/run/docker.sock:/var/run/docker.sock"
-        :param ebs_size: (experimental) Gitlab Runner instance EBS size . Default: - ebsSize=60
+        :param ebs_size: (deprecated) Gitlab Runner instance EBS size .
         :param ec2iamrole: (experimental) IAM role for the Gitlab Runner Instance . Default: - new Role for Gitlab Runner Instance , attach AmazonSSMManagedInstanceCore Policy .
         :param ec2type: (experimental) Runner default EC2 instance type. Default: - t3.micro
         :param enabled_imd_sv2: (experimental) Enabled IMDSv2. more detail see https://docs.aws.amazon.com/zh_tw/AWSEC2/latest/UserGuide/configuring-instance-metadata-service.html Default: - false
@@ -705,8 +725,10 @@ class GitlabContainerRunnerProps:
         :param gitlaburl: (experimental) Gitlab Runner register url . Default: - gitlaburl='https://gitlab.com/' , please use https://yourgitlab.com/ do not use https://yourgitlab.com
         :param instance_interruption_behavior: (experimental) The behavior when a Spot Runner Instance is interrupted. Default: - InstanceInterruptionBehavior.TERMINATE , !!! only support spotfleet runner !!! .
         :param key_name: (experimental) SSH key name. Default: - no ssh key will be assigned , !!! only support spotfleet runner !!! .
+        :param on_demand_ebs_config: (experimental) Gitlab Runner instance EBS config. Default: - onDemandEbsConfig=BlockDeviceVolume.ebs(60)
         :param runner_description: (experimental) Gitlab Runner description. Default: - runnerDescription='Docker Runner'
         :param selfvpc: (experimental) VPC for the Gitlab Runner . Default: - new VPC will be created , 1 Vpc , 2 Public Subnet .
+        :param spot_ebs_config: (experimental) Gitlab Runner instance EBS config. Default: - spotEbsConfig={ volumeSize: 60}
         :param spot_fleet: (experimental) Gitlab Runner instance Use Spot Fleet or not ?!. Default: - spotFleet=false
         :param tags: (experimental) tags for the runner Unsupported Gitlab Runner 15.10 and later. Default: - ['runner', 'gitlab', 'awscdk']
         :param valid_until: (experimental) the time when the spot fleet allocation expires. Default: - no expiration , !!! only support spotfleet runner !!! .
@@ -714,6 +736,8 @@ class GitlabContainerRunnerProps:
 
         :stability: experimental
         '''
+        if isinstance(spot_ebs_config, dict):
+            spot_ebs_config = _aws_cdk_aws_ec2_ceddda9d.CfnLaunchTemplate.EbsProperty(**spot_ebs_config)
         if isinstance(vpc_subnet, dict):
             vpc_subnet = _aws_cdk_aws_ec2_ceddda9d.SubnetSelection(**vpc_subnet)
         if __debug__:
@@ -730,8 +754,10 @@ class GitlabContainerRunnerProps:
             check_type(argname="argument gitlaburl", value=gitlaburl, expected_type=type_hints["gitlaburl"])
             check_type(argname="argument instance_interruption_behavior", value=instance_interruption_behavior, expected_type=type_hints["instance_interruption_behavior"])
             check_type(argname="argument key_name", value=key_name, expected_type=type_hints["key_name"])
+            check_type(argname="argument on_demand_ebs_config", value=on_demand_ebs_config, expected_type=type_hints["on_demand_ebs_config"])
             check_type(argname="argument runner_description", value=runner_description, expected_type=type_hints["runner_description"])
             check_type(argname="argument selfvpc", value=selfvpc, expected_type=type_hints["selfvpc"])
+            check_type(argname="argument spot_ebs_config", value=spot_ebs_config, expected_type=type_hints["spot_ebs_config"])
             check_type(argname="argument spot_fleet", value=spot_fleet, expected_type=type_hints["spot_fleet"])
             check_type(argname="argument tags", value=tags, expected_type=type_hints["tags"])
             check_type(argname="argument valid_until", value=valid_until, expected_type=type_hints["valid_until"])
@@ -760,10 +786,14 @@ class GitlabContainerRunnerProps:
             self._values["instance_interruption_behavior"] = instance_interruption_behavior
         if key_name is not None:
             self._values["key_name"] = key_name
+        if on_demand_ebs_config is not None:
+            self._values["on_demand_ebs_config"] = on_demand_ebs_config
         if runner_description is not None:
             self._values["runner_description"] = runner_description
         if selfvpc is not None:
             self._values["selfvpc"] = selfvpc
+        if spot_ebs_config is not None:
+            self._values["spot_ebs_config"] = spot_ebs_config
         if spot_fleet is not None:
             self._values["spot_fleet"] = spot_fleet
         if tags is not None:
@@ -838,15 +868,11 @@ class GitlabContainerRunnerProps:
 
     @builtins.property
     def ebs_size(self) -> typing.Optional[jsii.Number]:
-        '''(experimental) Gitlab Runner instance EBS size .
+        '''(deprecated) Gitlab Runner instance EBS size .
 
-        :default: - ebsSize=60
+        :deprecated: , use ebsConfig
 
-        :stability: experimental
-
-        Example::
-
-            const runner = new GitlabContainerRunner(stack, 'runner', { gitlabtoken: 'GITLAB_TOKEN',ebsSize: 100});
+        :stability: deprecated
         '''
         result = self._values.get("ebs_size")
         return typing.cast(typing.Optional[jsii.Number], result)
@@ -954,6 +980,23 @@ class GitlabContainerRunnerProps:
         result = self._values.get("key_name")
         return typing.cast(typing.Optional[builtins.str], result)
 
+    @builtins.property
+    def on_demand_ebs_config(
+        self,
+    ) -> typing.Optional[_aws_cdk_aws_ec2_ceddda9d.BlockDeviceVolume]:
+        '''(experimental) Gitlab Runner instance EBS config.
+
+        :default: - onDemandEbsConfig=BlockDeviceVolume.ebs(60)
+
+        :stability: experimental
+
+        Example::
+
+            const runner = new GitlabContainerRunner(stack, 'runner', { gitlabToken: 'GITLAB_TOKEN', onDemandEbsConfig: BlockDeviceVolume.ebs(60)});
+        '''
+        result = self._values.get("on_demand_ebs_config")
+        return typing.cast(typing.Optional[_aws_cdk_aws_ec2_ceddda9d.BlockDeviceVolume], result)
+
     @builtins.property
     def runner_description(self) -> typing.Optional[builtins.str]:
         '''(experimental) Gitlab Runner description.
@@ -995,6 +1038,23 @@ class GitlabContainerRunnerProps:
         result = self._values.get("selfvpc")
         return typing.cast(typing.Optional[_aws_cdk_aws_ec2_ceddda9d.IVpc], result)
 
+    @builtins.property
+    def spot_ebs_config(
+        self,
+    ) -> typing.Optional[_aws_cdk_aws_ec2_ceddda9d.CfnLaunchTemplate.EbsProperty]:
+        '''(experimental) Gitlab Runner instance EBS config.
+
+        :default: - spotEbsConfig={ volumeSize: 60}
+
+        :stability: experimental
+
+        Example::
+
+            const runner = new GitlabContainerRunner(stack, 'runner', { gitlabToken: 'GITLAB_TOKEN', ebsConfig: { volumeSize: 60}});
+        '''
+        result = self._values.get("spot_ebs_config")
+        return typing.cast(typing.Optional[_aws_cdk_aws_ec2_ceddda9d.CfnLaunchTemplate.EbsProperty], result)
+
     @builtins.property
     def spot_fleet(self) -> typing.Optional[builtins.bool]:
         '''(experimental) Gitlab Runner instance Use Spot Fleet or not ?!.
@@ -1051,7 +1111,6 @@ class GitlabContainerRunnerProps:
               gitlabtoken: 'GITLAB_TOKEN',
               ec2type: 't3.large',
               ec2iamrole: role,
-              ebsSize: 100,
               selfvpc: vpc,
               vpcSubnet: {
                 subnetType: SubnetType.PUBLIC,
@@ -1093,6 +1152,7 @@ class GitlabRunnerAutoscaling(
         alarms: typing.Optional[typing.Sequence[typing.Mapping[typing.Any, typing.Any]]] = None,
         desired_capacity: typing.Optional[jsii.Number] = None,
         docker_volumes: typing.Optional[typing.Sequence[typing.Union[DockerVolumes, typing.Dict[builtins.str, typing.Any]]]] = None,
+        ebs_config: typing.Optional[typing.Union[_aws_cdk_aws_ec2_ceddda9d.CfnLaunchTemplate.EbsProperty, typing.Dict[builtins.str, typing.Any]]] = None,
         ebs_size: typing.Optional[jsii.Number] = None,
         gitlab_runner_image: typing.Optional[builtins.str] = None,
         gitlab_url: typing.Optional[builtins.str] = None,
@@ -1113,7 +1173,8 @@ class GitlabRunnerAutoscaling(
         :param alarms: (experimental) Parameters of put_metric_alarm function. https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cloudwatch.html#CloudWatch.Client.put_metric_alarm Default: - [{ AlarmName: 'GitlabRunnerDiskUsage', MetricName: 'disk_used_percent', }]
         :param desired_capacity: (experimental) Desired capacity limit for autoscaling group. Default: - minCapacity, and leave unchanged during deployment
         :param docker_volumes: (experimental) add another Gitlab Container Runner Docker Volumes Path at job runner runtime. more detail see https://docs.gitlab.com/runner/configuration/advanced-configuration.html#the-runnersdocker-section Default: - already mount "/var/run/docker.sock:/var/run/docker.sock"
-        :param ebs_size: (experimental) Gitlab Runner instance EBS size . Default: - ebsSize=60
+        :param ebs_config: (experimental) Gitlab Runner instance EBS config. Default: - ebsConfig={ volumeSize: 60}
+        :param ebs_size: (deprecated) Gitlab Runner instance EBS size .
         :param gitlab_runner_image: (experimental) Image URL of Gitlab Runner. Default: public.ecr.aws/gitlab/gitlab-runner:latest
         :param gitlab_url: (experimental) Gitlab Runner register url . Default: - https://gitlab.com/ , The trailing slash is mandatory.
         :param instance_role: (experimental) IAM role for the Gitlab Runner Instance . Default: - new Role for Gitlab Runner Instance , attach AmazonSSMManagedInstanceCore Policy .
@@ -1137,6 +1198,7 @@ class GitlabRunnerAutoscaling(
             alarms=alarms,
             desired_capacity=desired_capacity,
             docker_volumes=docker_volumes,
+            ebs_config=ebs_config,
             ebs_size=ebs_size,
             gitlab_runner_image=gitlab_runner_image,
             gitlab_url=gitlab_url,
@@ -1161,6 +1223,7 @@ class GitlabRunnerAutoscaling(
         alarms: typing.Optional[typing.Sequence[typing.Mapping[typing.Any, typing.Any]]] = None,
         desired_capacity: typing.Optional[jsii.Number] = None,
         docker_volumes: typing.Optional[typing.Sequence[typing.Union[DockerVolumes, typing.Dict[builtins.str, typing.Any]]]] = None,
+        ebs_config: typing.Optional[typing.Union[_aws_cdk_aws_ec2_ceddda9d.CfnLaunchTemplate.EbsProperty, typing.Dict[builtins.str, typing.Any]]] = None,
         ebs_size: typing.Optional[jsii.Number] = None,
         gitlab_runner_image: typing.Optional[builtins.str] = None,
         gitlab_url: typing.Optional[builtins.str] = None,
@@ -1179,7 +1242,8 @@ class GitlabRunnerAutoscaling(
         :param alarms: (experimental) Parameters of put_metric_alarm function. https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cloudwatch.html#CloudWatch.Client.put_metric_alarm Default: - [{ AlarmName: 'GitlabRunnerDiskUsage', MetricName: 'disk_used_percent', }]
         :param desired_capacity: (experimental) Desired capacity limit for autoscaling group. Default: - minCapacity, and leave unchanged during deployment
         :param docker_volumes: (experimental) add another Gitlab Container Runner Docker Volumes Path at job runner runtime. more detail see https://docs.gitlab.com/runner/configuration/advanced-configuration.html#the-runnersdocker-section Default: - already mount "/var/run/docker.sock:/var/run/docker.sock"
-        :param ebs_size: (experimental) Gitlab Runner instance EBS size . Default: - ebsSize=60
+        :param ebs_config: (experimental) Gitlab Runner instance EBS config. Default: - ebsConfig={ volumeSize: 60}
+        :param ebs_size: (deprecated) Gitlab Runner instance EBS size .
         :param gitlab_runner_image: (experimental) Image URL of Gitlab Runner. Default: public.ecr.aws/gitlab/gitlab-runner:latest
         :param gitlab_url: (experimental) Gitlab Runner register url . Default: - https://gitlab.com/ , The trailing slash is mandatory.
         :param instance_role: (experimental) IAM role for the Gitlab Runner Instance . Default: - new Role for Gitlab Runner Instance , attach AmazonSSMManagedInstanceCore Policy .
@@ -1201,6 +1265,7 @@ class GitlabRunnerAutoscaling(
             alarms=alarms,
             desired_capacity=desired_capacity,
             docker_volumes=docker_volumes,
+            ebs_config=ebs_config,
             ebs_size=ebs_size,
             gitlab_runner_image=gitlab_runner_image,
             gitlab_url=gitlab_url,
@@ -1271,6 +1336,7 @@ class GitlabRunnerAutoscaling(
         "alarms": "alarms",
         "desired_capacity": "desiredCapacity",
         "docker_volumes": "dockerVolumes",
+        "ebs_config": "ebsConfig",
         "ebs_size": "ebsSize",
         "gitlab_runner_image": "gitlabRunnerImage",
         "gitlab_url": "gitlabUrl",
@@ -1293,6 +1359,7 @@ class GitlabRunnerAutoscalingProps:
         alarms: typing.Optional[typing.Sequence[typing.Mapping[typing.Any, typing.Any]]] = None,
         desired_capacity: typing.Optional[jsii.Number] = None,
         docker_volumes: typing.Optional[typing.Sequence[typing.Union[DockerVolumes, typing.Dict[builtins.str, typing.Any]]]] = None,
+        ebs_config: typing.Optional[typing.Union[_aws_cdk_aws_ec2_ceddda9d.CfnLaunchTemplate.EbsProperty, typing.Dict[builtins.str, typing.Any]]] = None,
         ebs_size: typing.Optional[jsii.Number] = None,
         gitlab_runner_image: typing.Optional[builtins.str] = None,
         gitlab_url: typing.Optional[builtins.str] = None,
@@ -1312,7 +1379,8 @@ class GitlabRunnerAutoscalingProps:
         :param alarms: (experimental) Parameters of put_metric_alarm function. https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cloudwatch.html#CloudWatch.Client.put_metric_alarm Default: - [{ AlarmName: 'GitlabRunnerDiskUsage', MetricName: 'disk_used_percent', }]
         :param desired_capacity: (experimental) Desired capacity limit for autoscaling group. Default: - minCapacity, and leave unchanged during deployment
         :param docker_volumes: (experimental) add another Gitlab Container Runner Docker Volumes Path at job runner runtime. more detail see https://docs.gitlab.com/runner/configuration/advanced-configuration.html#the-runnersdocker-section Default: - already mount "/var/run/docker.sock:/var/run/docker.sock"
-        :param ebs_size: (experimental) Gitlab Runner instance EBS size . Default: - ebsSize=60
+        :param ebs_config: (experimental) Gitlab Runner instance EBS config. Default: - ebsConfig={ volumeSize: 60}
+        :param ebs_size: (deprecated) Gitlab Runner instance EBS size .
         :param gitlab_runner_image: (experimental) Image URL of Gitlab Runner. Default: public.ecr.aws/gitlab/gitlab-runner:latest
         :param gitlab_url: (experimental) Gitlab Runner register url . Default: - https://gitlab.com/ , The trailing slash is mandatory.
         :param instance_role: (experimental) IAM role for the Gitlab Runner Instance . Default: - new Role for Gitlab Runner Instance , attach AmazonSSMManagedInstanceCore Policy .
@@ -1326,6 +1394,8 @@ class GitlabRunnerAutoscalingProps:
 
         :stability: experimental
         '''
+        if isinstance(ebs_config, dict):
+            ebs_config = _aws_cdk_aws_ec2_ceddda9d.CfnLaunchTemplate.EbsProperty(**ebs_config)
         if isinstance(vpc_subnet, dict):
             vpc_subnet = _aws_cdk_aws_ec2_ceddda9d.SubnetSelection(**vpc_subnet)
         if __debug__:
@@ -1335,6 +1405,7 @@ class GitlabRunnerAutoscalingProps:
             check_type(argname="argument alarms", value=alarms, expected_type=type_hints["alarms"])
             check_type(argname="argument desired_capacity", value=desired_capacity, expected_type=type_hints["desired_capacity"])
             check_type(argname="argument docker_volumes", value=docker_volumes, expected_type=type_hints["docker_volumes"])
+            check_type(argname="argument ebs_config", value=ebs_config, expected_type=type_hints["ebs_config"])
             check_type(argname="argument ebs_size", value=ebs_size, expected_type=type_hints["ebs_size"])
             check_type(argname="argument gitlab_runner_image", value=gitlab_runner_image, expected_type=type_hints["gitlab_runner_image"])
             check_type(argname="argument gitlab_url", value=gitlab_url, expected_type=type_hints["gitlab_url"])
@@ -1356,6 +1427,8 @@ class GitlabRunnerAutoscalingProps:
             self._values["desired_capacity"] = desired_capacity
         if docker_volumes is not None:
             self._values["docker_volumes"] = docker_volumes
+        if ebs_config is not None:
+            self._values["ebs_config"] = ebs_config
         if ebs_size is not None:
             self._values["ebs_size"] = ebs_size
         if gitlab_runner_image is not None:
@@ -1461,16 +1534,29 @@ class GitlabRunnerAutoscalingProps:
         return typing.cast(typing.Optional[typing.List[DockerVolumes]], result)
 
     @builtins.property
-    def ebs_size(self) -> typing.Optional[jsii.Number]:
-        '''(experimental) Gitlab Runner instance EBS size .
+    def ebs_config(
+        self,
+    ) -> typing.Optional[_aws_cdk_aws_ec2_ceddda9d.CfnLaunchTemplate.EbsProperty]:
+        '''(experimental) Gitlab Runner instance EBS config.
 
-        :default: - ebsSize=60
+        :default: - ebsConfig={ volumeSize: 60}
 
         :stability: experimental
 
         Example::
 
-            const runner = new GitlabRunnerAutoscaling(stack, 'runner', { gitlabToken: 'GITLAB_TOKEN', ebsSize: 100});
+            const runner = new GitlabRunnerAutoscaling(stack, 'runner', { gitlabToken: 'GITLAB_TOKEN', ebsConfig: { volumeSize: 60}});
+        '''
+        result = self._values.get("ebs_config")
+        return typing.cast(typing.Optional[_aws_cdk_aws_ec2_ceddda9d.CfnLaunchTemplate.EbsProperty], result)
+
+    @builtins.property
+    def ebs_size(self) -> typing.Optional[jsii.Number]:
+        '''(deprecated) Gitlab Runner instance EBS size .
+
+        :deprecated: , use ebsConfig
+
+        :stability: deprecated
         '''
         result = self._values.get("ebs_size")
         return typing.cast(typing.Optional[jsii.Number], result)
@@ -1637,7 +1723,6 @@ class GitlabRunnerAutoscalingProps:
               gitlabToken: 'GITLAB_TOKEN',
               instanceType: 't3.large',
               instanceRole: role,
-              ebsSize: 100,
               vpc: vpc,
               vpcSubnet: {
                 subnetType: SubnetType.PUBLIC,
@@ -1718,8 +1803,10 @@ def _typecheckingstub__3569128cd1ccb4f615528e61f1622fdbd79cb2ae3e5d8a3297d682bf4
     gitlaburl: typing.Optional[builtins.str] = None,
     instance_interruption_behavior: typing.Optional[InstanceInterruptionBehavior] = None,
     key_name: typing.Optional[builtins.str] = None,
+    on_demand_ebs_config: typing.Optional[_aws_cdk_aws_ec2_ceddda9d.BlockDeviceVolume] = None,
     runner_description: typing.Optional[builtins.str] = None,
     selfvpc: typing.Optional[_aws_cdk_aws_ec2_ceddda9d.IVpc] = None,
+    spot_ebs_config: typing.Optional[typing.Union[_aws_cdk_aws_ec2_ceddda9d.CfnLaunchTemplate.EbsProperty, typing.Dict[builtins.str, typing.Any]]] = None,
     spot_fleet: typing.Optional[builtins.bool] = None,
     tags: typing.Optional[typing.Sequence[builtins.str]] = None,
     valid_until: typing.Optional[builtins.str] = None,
@@ -1755,8 +1842,10 @@ def _typecheckingstub__0026c0e7fdafbb0c3cfac95f254acf8fbd8eb0fb39b8b1e9cd3089655
     gitlaburl: typing.Optional[builtins.str] = None,
     instance_interruption_behavior: typing.Optional[InstanceInterruptionBehavior] = None,
     key_name: typing.Optional[builtins.str] = None,
+    on_demand_ebs_config: typing.Optional[_aws_cdk_aws_ec2_ceddda9d.BlockDeviceVolume] = None,
     runner_description: typing.Optional[builtins.str] = None,
     selfvpc: typing.Optional[_aws_cdk_aws_ec2_ceddda9d.IVpc] = None,
+    spot_ebs_config: typing.Optional[typing.Union[_aws_cdk_aws_ec2_ceddda9d.CfnLaunchTemplate.EbsProperty, typing.Dict[builtins.str, typing.Any]]] = None,
     spot_fleet: typing.Optional[builtins.bool] = None,
     tags: typing.Optional[typing.Sequence[builtins.str]] = None,
     valid_until: typing.Optional[builtins.str] = None,
@@ -1774,6 +1863,7 @@ def _typecheckingstub__e1346a7c57bd8e3d5b6fd96e74f7310063137cbf2338091d3cb96f36a
     alarms: typing.Optional[typing.Sequence[typing.Mapping[typing.Any, typing.Any]]] = None,
     desired_capacity: typing.Optional[jsii.Number] = None,
     docker_volumes: typing.Optional[typing.Sequence[typing.Union[DockerVolumes, typing.Dict[builtins.str, typing.Any]]]] = None,
+    ebs_config: typing.Optional[typing.Union[_aws_cdk_aws_ec2_ceddda9d.CfnLaunchTemplate.EbsProperty, typing.Dict[builtins.str, typing.Any]]] = None,
     ebs_size: typing.Optional[jsii.Number] = None,
     gitlab_runner_image: typing.Optional[builtins.str] = None,
     gitlab_url: typing.Optional[builtins.str] = None,
@@ -1796,6 +1886,7 @@ def _typecheckingstub__456bc54665e983cecf5d286556d3b391003886fdd1d6f537def246750
     alarms: typing.Optional[typing.Sequence[typing.Mapping[typing.Any, typing.Any]]] = None,
     desired_capacity: typing.Optional[jsii.Number] = None,
     docker_volumes: typing.Optional[typing.Sequence[typing.Union[DockerVolumes, typing.Dict[builtins.str, typing.Any]]]] = None,
+    ebs_config: typing.Optional[typing.Union[_aws_cdk_aws_ec2_ceddda9d.CfnLaunchTemplate.EbsProperty, typing.Dict[builtins.str, typing.Any]]] = None,
     ebs_size: typing.Optional[jsii.Number] = None,
     gitlab_runner_image: typing.Optional[builtins.str] = None,
     gitlab_url: typing.Optional[builtins.str] = None,
